"""
Tests that sktran gem_mach modules is operating as expected.

Date: 2019-09-19

"""
import unittest, math
import numpy as np
from datetime import datetime
from sasktran_gcm import GEM_MACH

class QuickCoreTest(unittest.TestCase):
    """
    Test bench to run sanity checks on SASKTRAN GEM-MACH.
    """

    def test_fileio(self):
        climate = GEM_MACH()
        climate.set_gem_filename(r'\\datastore\valhalla\root\data_products\GEM\20180621_gemmach2p5.nc')
        climate.load_species('SKCLIMATOLOGY_NO2_CM3')
        climate.load_species('SKCLIMATOLOGY_NO2_VMR')
        latitude = 50.3456289
        longitude = 247.982739087
        utc = datetime.fromisoformat('2018-06-21T12:00:00.000000')
        climate.update_cache(latitude, longitude, utc)

        h = np.arange(0, 60000.0, 100.0)
        no2cm3 = climate.get_parameter('SKCLIMATOLOGY_NO2_CM3', latitude, longitude, h, utc)
        no2vmr = climate.get_parameter('SKCLIMATOLOGY_NO2_VMR', latitude, longitude, h, utc)
        self.assertAlmostEqual(no2vmr[27], 7.175307040758139421e-11, 19)
        self.assertAlmostEqual(no2cm3[27], 1.360467777700631380e+09,  3)

if __name__ == "__main__":
    if __name__ == "__main__":
        tests = QuickCoreTest()
        unittest.main()




