import os
import os.path
import sys

from sasktranif.sasktranif_registry import  SasktranifRegistry

#------------------------------------------------------------------------------
#           _rlinput
#------------------------------------------------------------------------------

def _rlinput(prompt, default =''):

    question = '{} [{}] ?:'.format(prompt,default)
    line = input(question)
    value = line.strip()
    if (len(value) < 1):
        line = default
    return line

#------------------------------------------------------------------------------
#           update_mie_aerosol_cache
#------------------------------------------------------------------------------

def _update_folder( prompt : str, skregistry: SasktranifRegistry, keyindexstring : str, response = None ):

    key,idx = keyindexstring.rsplit('/', maxsplit=1)
    folder   = skregistry.subkey(key)[idx]
    if (response is None):
        response = _rlinput("Enter the {} ".format(prompt), default = folder)
    if sys.platform == 'win32':
        response = response. replace('\\', '/')
    skregistry.subkey(key)[idx] = response

#------------------------------------------------------------------------------
#           display_menu
#------------------------------------------------------------------------------

def _display_menu(skregistry:SasktranifRegistry):

    id = 1

    folderarray = [  ['folder for the GEOS-CHEM database',           'software/usask-arg/climatology/geoschem5/storage/geoschem5dir']
                  ]

    while (id > 0):
        print("\nPackage options for the Sasktran GCM Components")
        print("-------------------------------------------------\n")
        for optionid in range(len(folderarray)):
            print("    {:2d}) {:<44s}-> {}".format( optionid+1, folderarray[optionid][0], skregistry.subkey(folderarray[optionid][1]) ))
        print("     0) Save and Exit")
        print("    -1) Quit and do not save")
        print("\n")
        selection = input('Enter your selection: ')
        try:
            id = int( selection)
        except:
            print('You must enter a valid interger. Defaulting to 9999')
            id = 9999

        if (id > 0):
            if id <= len(folderarray):
                _update_folder( folderarray[id-1][0], skregistry, folderarray[id-1][1])
            else:
                print("Unknown option {:d}".format(id) )
        else:
            if (id == 0):
                skregistry.save()
                print("The registry settings have been saved.")
            else:
                print("The registry settings have NOT been saved.")
    return id

#------------------------------------------------------------------------------
#           def modify_sasktran_core_registry_settings():
#------------------------------------------------------------------------------

def modify():
    skregistry = SasktranifRegistry()
    id = _display_menu(skregistry)
    print('Finished modifying sasktran_gcm registry settings')

if __name__ == "__main__":
    modify()
